# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['AuthBackendLoginArgs', 'AuthBackendLogin']

@pulumi.input_type
class AuthBackendLoginArgs:
    def __init__(__self__, *,
                 role_id: pulumi.Input[str],
                 backend: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 secret_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AuthBackendLogin resource.
        :param pulumi.Input[str] role_id: The ID of the role to log in with.
        :param pulumi.Input[str] backend: The unique path of the Vault backend to log in with.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] secret_id: The secret ID of the role to log in with. Required
               unless `bind_secret_id` is set to false on the role.
        """
        pulumi.set(__self__, "role_id", role_id)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if secret_id is not None:
            pulumi.set(__self__, "secret_id", secret_id)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Input[str]:
        """
        The ID of the role to log in with.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        The unique path of the Vault backend to log in with.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> Optional[pulumi.Input[str]]:
        """
        The secret ID of the role to log in with. Required
        unless `bind_secret_id` is set to false on the role.
        """
        return pulumi.get(self, "secret_id")

    @secret_id.setter
    def secret_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_id", value)


@pulumi.input_type
class _AuthBackendLoginState:
    def __init__(__self__, *,
                 accessor: Optional[pulumi.Input[str]] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 client_token: Optional[pulumi.Input[str]] = None,
                 lease_duration: Optional[pulumi.Input[int]] = None,
                 lease_started: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 renewable: Optional[pulumi.Input[bool]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 secret_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AuthBackendLogin resources.
        :param pulumi.Input[str] accessor: The accessor for the token.
        :param pulumi.Input[str] backend: The unique path of the Vault backend to log in with.
        :param pulumi.Input[str] client_token: The Vault token created.
        :param pulumi.Input[int] lease_duration: How long the token is valid for, in seconds.
        :param pulumi.Input[str] lease_started: The date and time the lease started, in RFC 3339 format.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: The metadata associated with the token.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: A list of policies applied to the token.
        :param pulumi.Input[bool] renewable: Whether the token is renewable or not.
        :param pulumi.Input[str] role_id: The ID of the role to log in with.
        :param pulumi.Input[str] secret_id: The secret ID of the role to log in with. Required
               unless `bind_secret_id` is set to false on the role.
        """
        if accessor is not None:
            pulumi.set(__self__, "accessor", accessor)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if client_token is not None:
            pulumi.set(__self__, "client_token", client_token)
        if lease_duration is not None:
            pulumi.set(__self__, "lease_duration", lease_duration)
        if lease_started is not None:
            pulumi.set(__self__, "lease_started", lease_started)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)
        if renewable is not None:
            pulumi.set(__self__, "renewable", renewable)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if secret_id is not None:
            pulumi.set(__self__, "secret_id", secret_id)

    @property
    @pulumi.getter
    def accessor(self) -> Optional[pulumi.Input[str]]:
        """
        The accessor for the token.
        """
        return pulumi.get(self, "accessor")

    @accessor.setter
    def accessor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "accessor", value)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        The unique path of the Vault backend to log in with.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="clientToken")
    def client_token(self) -> Optional[pulumi.Input[str]]:
        """
        The Vault token created.
        """
        return pulumi.get(self, "client_token")

    @client_token.setter
    def client_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_token", value)

    @property
    @pulumi.getter(name="leaseDuration")
    def lease_duration(self) -> Optional[pulumi.Input[int]]:
        """
        How long the token is valid for, in seconds.
        """
        return pulumi.get(self, "lease_duration")

    @lease_duration.setter
    def lease_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "lease_duration", value)

    @property
    @pulumi.getter(name="leaseStarted")
    def lease_started(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the lease started, in RFC 3339 format.
        """
        return pulumi.get(self, "lease_started")

    @lease_started.setter
    def lease_started(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lease_started", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The metadata associated with the token.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of policies applied to the token.
        """
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "policies", value)

    @property
    @pulumi.getter
    def renewable(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the token is renewable or not.
        """
        return pulumi.get(self, "renewable")

    @renewable.setter
    def renewable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "renewable", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the role to log in with.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> Optional[pulumi.Input[str]]:
        """
        The secret ID of the role to log in with. Required
        unless `bind_secret_id` is set to false on the role.
        """
        return pulumi.get(self, "secret_id")

    @secret_id.setter
    def secret_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_id", value)


class AuthBackendLogin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 secret_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Logs into Vault using the AppRole auth backend. See the [Vault
        documentation](https://www.vaultproject.io/docs/auth/approle) for more
        information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        approle = vault.AuthBackend("approle", type="approle")
        example = vault.app_role.AuthBackendRole("example",
            backend=approle.path,
            role_name="test-role",
            token_policies=[
                "default",
                "dev",
                "prod",
            ])
        id = vault.app_role.AuthBackendRoleSecretId("id",
            backend=approle.path,
            role_name=example.role_name)
        login = vault.app_role.AuthBackendLogin("login",
            backend=approle.path,
            role_id=example.role_id,
            secret_id=id.secret_id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: The unique path of the Vault backend to log in with.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] role_id: The ID of the role to log in with.
        :param pulumi.Input[str] secret_id: The secret ID of the role to log in with. Required
               unless `bind_secret_id` is set to false on the role.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AuthBackendLoginArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Logs into Vault using the AppRole auth backend. See the [Vault
        documentation](https://www.vaultproject.io/docs/auth/approle) for more
        information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        approle = vault.AuthBackend("approle", type="approle")
        example = vault.app_role.AuthBackendRole("example",
            backend=approle.path,
            role_name="test-role",
            token_policies=[
                "default",
                "dev",
                "prod",
            ])
        id = vault.app_role.AuthBackendRoleSecretId("id",
            backend=approle.path,
            role_name=example.role_name)
        login = vault.app_role.AuthBackendLogin("login",
            backend=approle.path,
            role_id=example.role_id,
            secret_id=id.secret_id)
        ```

        :param str resource_name: The name of the resource.
        :param AuthBackendLoginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthBackendLoginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 secret_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthBackendLoginArgs.__new__(AuthBackendLoginArgs)

            __props__.__dict__["backend"] = backend
            __props__.__dict__["namespace"] = namespace
            if role_id is None and not opts.urn:
                raise TypeError("Missing required property 'role_id'")
            __props__.__dict__["role_id"] = role_id
            __props__.__dict__["secret_id"] = None if secret_id is None else pulumi.Output.secret(secret_id)
            __props__.__dict__["accessor"] = None
            __props__.__dict__["client_token"] = None
            __props__.__dict__["lease_duration"] = None
            __props__.__dict__["lease_started"] = None
            __props__.__dict__["metadata"] = None
            __props__.__dict__["policies"] = None
            __props__.__dict__["renewable"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["clientToken", "secretId"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(AuthBackendLogin, __self__).__init__(
            'vault:appRole/authBackendLogin:AuthBackendLogin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accessor: Optional[pulumi.Input[str]] = None,
            backend: Optional[pulumi.Input[str]] = None,
            client_token: Optional[pulumi.Input[str]] = None,
            lease_duration: Optional[pulumi.Input[int]] = None,
            lease_started: Optional[pulumi.Input[str]] = None,
            metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            renewable: Optional[pulumi.Input[bool]] = None,
            role_id: Optional[pulumi.Input[str]] = None,
            secret_id: Optional[pulumi.Input[str]] = None) -> 'AuthBackendLogin':
        """
        Get an existing AuthBackendLogin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accessor: The accessor for the token.
        :param pulumi.Input[str] backend: The unique path of the Vault backend to log in with.
        :param pulumi.Input[str] client_token: The Vault token created.
        :param pulumi.Input[int] lease_duration: How long the token is valid for, in seconds.
        :param pulumi.Input[str] lease_started: The date and time the lease started, in RFC 3339 format.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: The metadata associated with the token.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: A list of policies applied to the token.
        :param pulumi.Input[bool] renewable: Whether the token is renewable or not.
        :param pulumi.Input[str] role_id: The ID of the role to log in with.
        :param pulumi.Input[str] secret_id: The secret ID of the role to log in with. Required
               unless `bind_secret_id` is set to false on the role.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthBackendLoginState.__new__(_AuthBackendLoginState)

        __props__.__dict__["accessor"] = accessor
        __props__.__dict__["backend"] = backend
        __props__.__dict__["client_token"] = client_token
        __props__.__dict__["lease_duration"] = lease_duration
        __props__.__dict__["lease_started"] = lease_started
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["policies"] = policies
        __props__.__dict__["renewable"] = renewable
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["secret_id"] = secret_id
        return AuthBackendLogin(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def accessor(self) -> pulumi.Output[str]:
        """
        The accessor for the token.
        """
        return pulumi.get(self, "accessor")

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Output[Optional[str]]:
        """
        The unique path of the Vault backend to log in with.
        """
        return pulumi.get(self, "backend")

    @property
    @pulumi.getter(name="clientToken")
    def client_token(self) -> pulumi.Output[str]:
        """
        The Vault token created.
        """
        return pulumi.get(self, "client_token")

    @property
    @pulumi.getter(name="leaseDuration")
    def lease_duration(self) -> pulumi.Output[int]:
        """
        How long the token is valid for, in seconds.
        """
        return pulumi.get(self, "lease_duration")

    @property
    @pulumi.getter(name="leaseStarted")
    def lease_started(self) -> pulumi.Output[str]:
        """
        The date and time the lease started, in RFC 3339 format.
        """
        return pulumi.get(self, "lease_started")

    @property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[Mapping[str, str]]:
        """
        The metadata associated with the token.
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def policies(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of policies applied to the token.
        """
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter
    def renewable(self) -> pulumi.Output[bool]:
        """
        Whether the token is renewable or not.
        """
        return pulumi.get(self, "renewable")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[str]:
        """
        The ID of the role to log in with.
        """
        return pulumi.get(self, "role_id")

    @property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> pulumi.Output[Optional[str]]:
        """
        The secret ID of the role to log in with. Required
        unless `bind_secret_id` is set to false on the role.
        """
        return pulumi.get(self, "secret_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SecretCredsArgs', 'SecretCreds']

@pulumi.input_type
class SecretCredsArgs:
    def __init__(__self__, *,
                 backend: pulumi.Input[str],
                 role: pulumi.Input[str],
                 namespace: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SecretCreds resource.
        :param pulumi.Input[str] backend: Terraform Cloud secret backend to generate tokens from
        :param pulumi.Input[str] role: Name of the role.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        """
        pulumi.set(__self__, "backend", backend)
        pulumi.set(__self__, "role", role)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Input[str]:
        """
        Terraform Cloud secret backend to generate tokens from
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: pulumi.Input[str]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Input[str]:
        """
        Name of the role.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[str]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)


@pulumi.input_type
class _SecretCredsState:
    def __init__(__self__, *,
                 backend: Optional[pulumi.Input[str]] = None,
                 lease_id: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 team_id: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 token_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SecretCreds resources.
        :param pulumi.Input[str] backend: Terraform Cloud secret backend to generate tokens from
        :param pulumi.Input[str] lease_id: The lease associated with the token. Only user tokens will have a 
               Vault lease associated with them.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] organization: The organization associated with the token provided.
        :param pulumi.Input[str] role: Name of the role.
        :param pulumi.Input[str] team_id: The team id associated with the token provided.
        :param pulumi.Input[str] token: The actual token that was generated and can be used with API calls
               to identify the user of the call.
        :param pulumi.Input[str] token_id: The public identifier for a specific token. It can be used 
               to look up information about a token or to revoke a token.
        """
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if lease_id is not None:
            pulumi.set(__self__, "lease_id", lease_id)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if token_id is not None:
            pulumi.set(__self__, "token_id", token_id)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        Terraform Cloud secret backend to generate tokens from
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="leaseId")
    def lease_id(self) -> Optional[pulumi.Input[str]]:
        """
        The lease associated with the token. Only user tokens will have a 
        Vault lease associated with them.
        """
        return pulumi.get(self, "lease_id")

    @lease_id.setter
    def lease_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lease_id", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The organization associated with the token provided.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the role.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[str]]:
        """
        The team id associated with the token provided.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[str]]:
        """
        The actual token that was generated and can be used with API calls
        to identify the user of the call.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter(name="tokenId")
    def token_id(self) -> Optional[pulumi.Input[str]]:
        """
        The public identifier for a specific token. It can be used 
        to look up information about a token or to revoke a token.
        """
        return pulumi.get(self, "token_id")

    @token_id.setter
    def token_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token_id", value)


class SecretCreds(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        test = vault.terraformcloud.SecretBackend("test",
            backend="terraform",
            description="Manages the Terraform Cloud backend",
            token="V0idfhi2iksSDU234ucdbi2nidsi...")
        example = vault.terraformcloud.SecretRole("example",
            backend=test.backend,
            organization="example-organization-name",
            team_id="team-ieF4isC...")
        token = vault.terraformcloud.SecretCreds("token",
            backend=test.backend,
            role=example.name)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: Terraform Cloud secret backend to generate tokens from
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] role: Name of the role.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecretCredsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        test = vault.terraformcloud.SecretBackend("test",
            backend="terraform",
            description="Manages the Terraform Cloud backend",
            token="V0idfhi2iksSDU234ucdbi2nidsi...")
        example = vault.terraformcloud.SecretRole("example",
            backend=test.backend,
            organization="example-organization-name",
            team_id="team-ieF4isC...")
        token = vault.terraformcloud.SecretCreds("token",
            backend=test.backend,
            role=example.name)
        ```

        :param str resource_name: The name of the resource.
        :param SecretCredsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretCredsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretCredsArgs.__new__(SecretCredsArgs)

            if backend is None and not opts.urn:
                raise TypeError("Missing required property 'backend'")
            __props__.__dict__["backend"] = backend
            __props__.__dict__["namespace"] = namespace
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
            __props__.__dict__["lease_id"] = None
            __props__.__dict__["organization"] = None
            __props__.__dict__["team_id"] = None
            __props__.__dict__["token"] = None
            __props__.__dict__["token_id"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["leaseId", "token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SecretCreds, __self__).__init__(
            'vault:terraformcloud/secretCreds:SecretCreds',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend: Optional[pulumi.Input[str]] = None,
            lease_id: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            organization: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None,
            team_id: Optional[pulumi.Input[str]] = None,
            token: Optional[pulumi.Input[str]] = None,
            token_id: Optional[pulumi.Input[str]] = None) -> 'SecretCreds':
        """
        Get an existing SecretCreds resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: Terraform Cloud secret backend to generate tokens from
        :param pulumi.Input[str] lease_id: The lease associated with the token. Only user tokens will have a 
               Vault lease associated with them.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] organization: The organization associated with the token provided.
        :param pulumi.Input[str] role: Name of the role.
        :param pulumi.Input[str] team_id: The team id associated with the token provided.
        :param pulumi.Input[str] token: The actual token that was generated and can be used with API calls
               to identify the user of the call.
        :param pulumi.Input[str] token_id: The public identifier for a specific token. It can be used 
               to look up information about a token or to revoke a token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretCredsState.__new__(_SecretCredsState)

        __props__.__dict__["backend"] = backend
        __props__.__dict__["lease_id"] = lease_id
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["organization"] = organization
        __props__.__dict__["role"] = role
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["token"] = token
        __props__.__dict__["token_id"] = token_id
        return SecretCreds(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Output[str]:
        """
        Terraform Cloud secret backend to generate tokens from
        """
        return pulumi.get(self, "backend")

    @property
    @pulumi.getter(name="leaseId")
    def lease_id(self) -> pulumi.Output[str]:
        """
        The lease associated with the token. Only user tokens will have a 
        Vault lease associated with them.
        """
        return pulumi.get(self, "lease_id")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        The organization associated with the token provided.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        """
        Name of the role.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[str]:
        """
        The team id associated with the token provided.
        """
        return pulumi.get(self, "team_id")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[str]:
        """
        The actual token that was generated and can be used with API calls
        to identify the user of the call.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter(name="tokenId")
    def token_id(self) -> pulumi.Output[str]:
        """
        The public identifier for a specific token. It can be used 
        to look up information about a token or to revoke a token.
        """
        return pulumi.get(self, "token_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SecretRoleArgs', 'SecretRole']

@pulumi.input_type
class SecretRoleArgs:
    def __init__(__self__, *,
                 path: pulumi.Input[str],
                 role: pulumi.Input[str],
                 scope: pulumi.Input[str],
                 namespace: Optional[pulumi.Input[str]] = None,
                 operation_activate: Optional[pulumi.Input[bool]] = None,
                 operation_add_attribute: Optional[pulumi.Input[bool]] = None,
                 operation_all: Optional[pulumi.Input[bool]] = None,
                 operation_create: Optional[pulumi.Input[bool]] = None,
                 operation_destroy: Optional[pulumi.Input[bool]] = None,
                 operation_discover_versions: Optional[pulumi.Input[bool]] = None,
                 operation_get: Optional[pulumi.Input[bool]] = None,
                 operation_get_attribute_list: Optional[pulumi.Input[bool]] = None,
                 operation_get_attributes: Optional[pulumi.Input[bool]] = None,
                 operation_locate: Optional[pulumi.Input[bool]] = None,
                 operation_none: Optional[pulumi.Input[bool]] = None,
                 operation_register: Optional[pulumi.Input[bool]] = None,
                 operation_rekey: Optional[pulumi.Input[bool]] = None,
                 operation_revoke: Optional[pulumi.Input[bool]] = None,
                 tls_client_key_bits: Optional[pulumi.Input[int]] = None,
                 tls_client_key_type: Optional[pulumi.Input[str]] = None,
                 tls_client_ttl: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a SecretRole resource.
        :param pulumi.Input[str] path: The unique path this backend should be mounted at. Must
               not begin or end with a `/`. Defaults to `kmip`.
        :param pulumi.Input[str] role: Name of the role.
        :param pulumi.Input[str] scope: Name of the scope.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] operation_activate: Grant permission to use the KMIP Activate operation.
        :param pulumi.Input[bool] operation_add_attribute: Grant permission to use the KMIP Add Attribute operation.
        :param pulumi.Input[bool] operation_all: Grant all permissions to this role. May not be specified with any other `operation_*` params.
        :param pulumi.Input[bool] operation_create: Grant permission to use the KMIP Create operation.
        :param pulumi.Input[bool] operation_destroy: Grant permission to use the KMIP Destroy operation.
        :param pulumi.Input[bool] operation_discover_versions: Grant permission to use the KMIP Discover Version operation.
        :param pulumi.Input[bool] operation_get: Grant permission to use the KMIP Get operation.
        :param pulumi.Input[bool] operation_get_attribute_list: Grant permission to use the KMIP Get Atrribute List operation.
        :param pulumi.Input[bool] operation_get_attributes: Grant permission to use the KMIP Get Atrributes operation.
        :param pulumi.Input[bool] operation_locate: Grant permission to use the KMIP Get Locate operation.
        :param pulumi.Input[bool] operation_none: Remove all permissions from this role. May not be specified with any other `operation_*` params.
        :param pulumi.Input[bool] operation_register: Grant permission to use the KMIP Register operation.
        :param pulumi.Input[bool] operation_rekey: Grant permission to use the KMIP Rekey operation.
        :param pulumi.Input[bool] operation_revoke: Grant permission to use the KMIP Revoke operation.
        :param pulumi.Input[int] tls_client_key_bits: Client certificate key bits, valid values depend on key type.
        :param pulumi.Input[str] tls_client_key_type: Client certificate key type, `rsa` or `ec`.
        :param pulumi.Input[int] tls_client_ttl: Client certificate TTL in seconds.
        """
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "role", role)
        pulumi.set(__self__, "scope", scope)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if operation_activate is not None:
            pulumi.set(__self__, "operation_activate", operation_activate)
        if operation_add_attribute is not None:
            pulumi.set(__self__, "operation_add_attribute", operation_add_attribute)
        if operation_all is not None:
            pulumi.set(__self__, "operation_all", operation_all)
        if operation_create is not None:
            pulumi.set(__self__, "operation_create", operation_create)
        if operation_destroy is not None:
            pulumi.set(__self__, "operation_destroy", operation_destroy)
        if operation_discover_versions is not None:
            pulumi.set(__self__, "operation_discover_versions", operation_discover_versions)
        if operation_get is not None:
            pulumi.set(__self__, "operation_get", operation_get)
        if operation_get_attribute_list is not None:
            pulumi.set(__self__, "operation_get_attribute_list", operation_get_attribute_list)
        if operation_get_attributes is not None:
            pulumi.set(__self__, "operation_get_attributes", operation_get_attributes)
        if operation_locate is not None:
            pulumi.set(__self__, "operation_locate", operation_locate)
        if operation_none is not None:
            pulumi.set(__self__, "operation_none", operation_none)
        if operation_register is not None:
            pulumi.set(__self__, "operation_register", operation_register)
        if operation_rekey is not None:
            pulumi.set(__self__, "operation_rekey", operation_rekey)
        if operation_revoke is not None:
            pulumi.set(__self__, "operation_revoke", operation_revoke)
        if tls_client_key_bits is not None:
            pulumi.set(__self__, "tls_client_key_bits", tls_client_key_bits)
        if tls_client_key_type is not None:
            pulumi.set(__self__, "tls_client_key_type", tls_client_key_type)
        if tls_client_ttl is not None:
            pulumi.set(__self__, "tls_client_ttl", tls_client_ttl)

    @property
    @pulumi.getter
    def path(self) -> pulumi.Input[str]:
        """
        The unique path this backend should be mounted at. Must
        not begin or end with a `/`. Defaults to `kmip`.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[str]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Input[str]:
        """
        Name of the role.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[str]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def scope(self) -> pulumi.Input[str]:
        """
        Name of the scope.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: pulumi.Input[str]):
        pulumi.set(self, "scope", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="operationActivate")
    def operation_activate(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Activate operation.
        """
        return pulumi.get(self, "operation_activate")

    @operation_activate.setter
    def operation_activate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_activate", value)

    @property
    @pulumi.getter(name="operationAddAttribute")
    def operation_add_attribute(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Add Attribute operation.
        """
        return pulumi.get(self, "operation_add_attribute")

    @operation_add_attribute.setter
    def operation_add_attribute(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_add_attribute", value)

    @property
    @pulumi.getter(name="operationAll")
    def operation_all(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant all permissions to this role. May not be specified with any other `operation_*` params.
        """
        return pulumi.get(self, "operation_all")

    @operation_all.setter
    def operation_all(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_all", value)

    @property
    @pulumi.getter(name="operationCreate")
    def operation_create(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Create operation.
        """
        return pulumi.get(self, "operation_create")

    @operation_create.setter
    def operation_create(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_create", value)

    @property
    @pulumi.getter(name="operationDestroy")
    def operation_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Destroy operation.
        """
        return pulumi.get(self, "operation_destroy")

    @operation_destroy.setter
    def operation_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_destroy", value)

    @property
    @pulumi.getter(name="operationDiscoverVersions")
    def operation_discover_versions(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Discover Version operation.
        """
        return pulumi.get(self, "operation_discover_versions")

    @operation_discover_versions.setter
    def operation_discover_versions(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_discover_versions", value)

    @property
    @pulumi.getter(name="operationGet")
    def operation_get(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Get operation.
        """
        return pulumi.get(self, "operation_get")

    @operation_get.setter
    def operation_get(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_get", value)

    @property
    @pulumi.getter(name="operationGetAttributeList")
    def operation_get_attribute_list(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Get Atrribute List operation.
        """
        return pulumi.get(self, "operation_get_attribute_list")

    @operation_get_attribute_list.setter
    def operation_get_attribute_list(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_get_attribute_list", value)

    @property
    @pulumi.getter(name="operationGetAttributes")
    def operation_get_attributes(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Get Atrributes operation.
        """
        return pulumi.get(self, "operation_get_attributes")

    @operation_get_attributes.setter
    def operation_get_attributes(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_get_attributes", value)

    @property
    @pulumi.getter(name="operationLocate")
    def operation_locate(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Get Locate operation.
        """
        return pulumi.get(self, "operation_locate")

    @operation_locate.setter
    def operation_locate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_locate", value)

    @property
    @pulumi.getter(name="operationNone")
    def operation_none(self) -> Optional[pulumi.Input[bool]]:
        """
        Remove all permissions from this role. May not be specified with any other `operation_*` params.
        """
        return pulumi.get(self, "operation_none")

    @operation_none.setter
    def operation_none(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_none", value)

    @property
    @pulumi.getter(name="operationRegister")
    def operation_register(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Register operation.
        """
        return pulumi.get(self, "operation_register")

    @operation_register.setter
    def operation_register(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_register", value)

    @property
    @pulumi.getter(name="operationRekey")
    def operation_rekey(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Rekey operation.
        """
        return pulumi.get(self, "operation_rekey")

    @operation_rekey.setter
    def operation_rekey(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_rekey", value)

    @property
    @pulumi.getter(name="operationRevoke")
    def operation_revoke(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Revoke operation.
        """
        return pulumi.get(self, "operation_revoke")

    @operation_revoke.setter
    def operation_revoke(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_revoke", value)

    @property
    @pulumi.getter(name="tlsClientKeyBits")
    def tls_client_key_bits(self) -> Optional[pulumi.Input[int]]:
        """
        Client certificate key bits, valid values depend on key type.
        """
        return pulumi.get(self, "tls_client_key_bits")

    @tls_client_key_bits.setter
    def tls_client_key_bits(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tls_client_key_bits", value)

    @property
    @pulumi.getter(name="tlsClientKeyType")
    def tls_client_key_type(self) -> Optional[pulumi.Input[str]]:
        """
        Client certificate key type, `rsa` or `ec`.
        """
        return pulumi.get(self, "tls_client_key_type")

    @tls_client_key_type.setter
    def tls_client_key_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tls_client_key_type", value)

    @property
    @pulumi.getter(name="tlsClientTtl")
    def tls_client_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        Client certificate TTL in seconds.
        """
        return pulumi.get(self, "tls_client_ttl")

    @tls_client_ttl.setter
    def tls_client_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tls_client_ttl", value)


@pulumi.input_type
class _SecretRoleState:
    def __init__(__self__, *,
                 namespace: Optional[pulumi.Input[str]] = None,
                 operation_activate: Optional[pulumi.Input[bool]] = None,
                 operation_add_attribute: Optional[pulumi.Input[bool]] = None,
                 operation_all: Optional[pulumi.Input[bool]] = None,
                 operation_create: Optional[pulumi.Input[bool]] = None,
                 operation_destroy: Optional[pulumi.Input[bool]] = None,
                 operation_discover_versions: Optional[pulumi.Input[bool]] = None,
                 operation_get: Optional[pulumi.Input[bool]] = None,
                 operation_get_attribute_list: Optional[pulumi.Input[bool]] = None,
                 operation_get_attributes: Optional[pulumi.Input[bool]] = None,
                 operation_locate: Optional[pulumi.Input[bool]] = None,
                 operation_none: Optional[pulumi.Input[bool]] = None,
                 operation_register: Optional[pulumi.Input[bool]] = None,
                 operation_rekey: Optional[pulumi.Input[bool]] = None,
                 operation_revoke: Optional[pulumi.Input[bool]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 tls_client_key_bits: Optional[pulumi.Input[int]] = None,
                 tls_client_key_type: Optional[pulumi.Input[str]] = None,
                 tls_client_ttl: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering SecretRole resources.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] operation_activate: Grant permission to use the KMIP Activate operation.
        :param pulumi.Input[bool] operation_add_attribute: Grant permission to use the KMIP Add Attribute operation.
        :param pulumi.Input[bool] operation_all: Grant all permissions to this role. May not be specified with any other `operation_*` params.
        :param pulumi.Input[bool] operation_create: Grant permission to use the KMIP Create operation.
        :param pulumi.Input[bool] operation_destroy: Grant permission to use the KMIP Destroy operation.
        :param pulumi.Input[bool] operation_discover_versions: Grant permission to use the KMIP Discover Version operation.
        :param pulumi.Input[bool] operation_get: Grant permission to use the KMIP Get operation.
        :param pulumi.Input[bool] operation_get_attribute_list: Grant permission to use the KMIP Get Atrribute List operation.
        :param pulumi.Input[bool] operation_get_attributes: Grant permission to use the KMIP Get Atrributes operation.
        :param pulumi.Input[bool] operation_locate: Grant permission to use the KMIP Get Locate operation.
        :param pulumi.Input[bool] operation_none: Remove all permissions from this role. May not be specified with any other `operation_*` params.
        :param pulumi.Input[bool] operation_register: Grant permission to use the KMIP Register operation.
        :param pulumi.Input[bool] operation_rekey: Grant permission to use the KMIP Rekey operation.
        :param pulumi.Input[bool] operation_revoke: Grant permission to use the KMIP Revoke operation.
        :param pulumi.Input[str] path: The unique path this backend should be mounted at. Must
               not begin or end with a `/`. Defaults to `kmip`.
        :param pulumi.Input[str] role: Name of the role.
        :param pulumi.Input[str] scope: Name of the scope.
        :param pulumi.Input[int] tls_client_key_bits: Client certificate key bits, valid values depend on key type.
        :param pulumi.Input[str] tls_client_key_type: Client certificate key type, `rsa` or `ec`.
        :param pulumi.Input[int] tls_client_ttl: Client certificate TTL in seconds.
        """
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if operation_activate is not None:
            pulumi.set(__self__, "operation_activate", operation_activate)
        if operation_add_attribute is not None:
            pulumi.set(__self__, "operation_add_attribute", operation_add_attribute)
        if operation_all is not None:
            pulumi.set(__self__, "operation_all", operation_all)
        if operation_create is not None:
            pulumi.set(__self__, "operation_create", operation_create)
        if operation_destroy is not None:
            pulumi.set(__self__, "operation_destroy", operation_destroy)
        if operation_discover_versions is not None:
            pulumi.set(__self__, "operation_discover_versions", operation_discover_versions)
        if operation_get is not None:
            pulumi.set(__self__, "operation_get", operation_get)
        if operation_get_attribute_list is not None:
            pulumi.set(__self__, "operation_get_attribute_list", operation_get_attribute_list)
        if operation_get_attributes is not None:
            pulumi.set(__self__, "operation_get_attributes", operation_get_attributes)
        if operation_locate is not None:
            pulumi.set(__self__, "operation_locate", operation_locate)
        if operation_none is not None:
            pulumi.set(__self__, "operation_none", operation_none)
        if operation_register is not None:
            pulumi.set(__self__, "operation_register", operation_register)
        if operation_rekey is not None:
            pulumi.set(__self__, "operation_rekey", operation_rekey)
        if operation_revoke is not None:
            pulumi.set(__self__, "operation_revoke", operation_revoke)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)
        if tls_client_key_bits is not None:
            pulumi.set(__self__, "tls_client_key_bits", tls_client_key_bits)
        if tls_client_key_type is not None:
            pulumi.set(__self__, "tls_client_key_type", tls_client_key_type)
        if tls_client_ttl is not None:
            pulumi.set(__self__, "tls_client_ttl", tls_client_ttl)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="operationActivate")
    def operation_activate(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Activate operation.
        """
        return pulumi.get(self, "operation_activate")

    @operation_activate.setter
    def operation_activate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_activate", value)

    @property
    @pulumi.getter(name="operationAddAttribute")
    def operation_add_attribute(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Add Attribute operation.
        """
        return pulumi.get(self, "operation_add_attribute")

    @operation_add_attribute.setter
    def operation_add_attribute(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_add_attribute", value)

    @property
    @pulumi.getter(name="operationAll")
    def operation_all(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant all permissions to this role. May not be specified with any other `operation_*` params.
        """
        return pulumi.get(self, "operation_all")

    @operation_all.setter
    def operation_all(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_all", value)

    @property
    @pulumi.getter(name="operationCreate")
    def operation_create(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Create operation.
        """
        return pulumi.get(self, "operation_create")

    @operation_create.setter
    def operation_create(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_create", value)

    @property
    @pulumi.getter(name="operationDestroy")
    def operation_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Destroy operation.
        """
        return pulumi.get(self, "operation_destroy")

    @operation_destroy.setter
    def operation_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_destroy", value)

    @property
    @pulumi.getter(name="operationDiscoverVersions")
    def operation_discover_versions(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Discover Version operation.
        """
        return pulumi.get(self, "operation_discover_versions")

    @operation_discover_versions.setter
    def operation_discover_versions(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_discover_versions", value)

    @property
    @pulumi.getter(name="operationGet")
    def operation_get(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Get operation.
        """
        return pulumi.get(self, "operation_get")

    @operation_get.setter
    def operation_get(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_get", value)

    @property
    @pulumi.getter(name="operationGetAttributeList")
    def operation_get_attribute_list(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Get Atrribute List operation.
        """
        return pulumi.get(self, "operation_get_attribute_list")

    @operation_get_attribute_list.setter
    def operation_get_attribute_list(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_get_attribute_list", value)

    @property
    @pulumi.getter(name="operationGetAttributes")
    def operation_get_attributes(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Get Atrributes operation.
        """
        return pulumi.get(self, "operation_get_attributes")

    @operation_get_attributes.setter
    def operation_get_attributes(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_get_attributes", value)

    @property
    @pulumi.getter(name="operationLocate")
    def operation_locate(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Get Locate operation.
        """
        return pulumi.get(self, "operation_locate")

    @operation_locate.setter
    def operation_locate(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_locate", value)

    @property
    @pulumi.getter(name="operationNone")
    def operation_none(self) -> Optional[pulumi.Input[bool]]:
        """
        Remove all permissions from this role. May not be specified with any other `operation_*` params.
        """
        return pulumi.get(self, "operation_none")

    @operation_none.setter
    def operation_none(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_none", value)

    @property
    @pulumi.getter(name="operationRegister")
    def operation_register(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Register operation.
        """
        return pulumi.get(self, "operation_register")

    @operation_register.setter
    def operation_register(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_register", value)

    @property
    @pulumi.getter(name="operationRekey")
    def operation_rekey(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Rekey operation.
        """
        return pulumi.get(self, "operation_rekey")

    @operation_rekey.setter
    def operation_rekey(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_rekey", value)

    @property
    @pulumi.getter(name="operationRevoke")
    def operation_revoke(self) -> Optional[pulumi.Input[bool]]:
        """
        Grant permission to use the KMIP Revoke operation.
        """
        return pulumi.get(self, "operation_revoke")

    @operation_revoke.setter
    def operation_revoke(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "operation_revoke", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The unique path this backend should be mounted at. Must
        not begin or end with a `/`. Defaults to `kmip`.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the role.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the scope.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scope", value)

    @property
    @pulumi.getter(name="tlsClientKeyBits")
    def tls_client_key_bits(self) -> Optional[pulumi.Input[int]]:
        """
        Client certificate key bits, valid values depend on key type.
        """
        return pulumi.get(self, "tls_client_key_bits")

    @tls_client_key_bits.setter
    def tls_client_key_bits(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tls_client_key_bits", value)

    @property
    @pulumi.getter(name="tlsClientKeyType")
    def tls_client_key_type(self) -> Optional[pulumi.Input[str]]:
        """
        Client certificate key type, `rsa` or `ec`.
        """
        return pulumi.get(self, "tls_client_key_type")

    @tls_client_key_type.setter
    def tls_client_key_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tls_client_key_type", value)

    @property
    @pulumi.getter(name="tlsClientTtl")
    def tls_client_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        Client certificate TTL in seconds.
        """
        return pulumi.get(self, "tls_client_ttl")

    @tls_client_ttl.setter
    def tls_client_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tls_client_ttl", value)


class SecretRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 operation_activate: Optional[pulumi.Input[bool]] = None,
                 operation_add_attribute: Optional[pulumi.Input[bool]] = None,
                 operation_all: Optional[pulumi.Input[bool]] = None,
                 operation_create: Optional[pulumi.Input[bool]] = None,
                 operation_destroy: Optional[pulumi.Input[bool]] = None,
                 operation_discover_versions: Optional[pulumi.Input[bool]] = None,
                 operation_get: Optional[pulumi.Input[bool]] = None,
                 operation_get_attribute_list: Optional[pulumi.Input[bool]] = None,
                 operation_get_attributes: Optional[pulumi.Input[bool]] = None,
                 operation_locate: Optional[pulumi.Input[bool]] = None,
                 operation_none: Optional[pulumi.Input[bool]] = None,
                 operation_register: Optional[pulumi.Input[bool]] = None,
                 operation_rekey: Optional[pulumi.Input[bool]] = None,
                 operation_revoke: Optional[pulumi.Input[bool]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 tls_client_key_bits: Optional[pulumi.Input[int]] = None,
                 tls_client_key_type: Optional[pulumi.Input[str]] = None,
                 tls_client_ttl: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Manages KMIP Secret roles in a Vault server. This feature requires
        Vault Enterprise. See the [Vault documentation](https://www.vaultproject.io/docs/secrets/kmip)
        for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        default = vault.kmip.SecretBackend("default",
            path="kmip",
            description="Vault KMIP backend")
        dev = vault.kmip.SecretScope("dev",
            path=default.path,
            scope="dev",
            force=True)
        admin = vault.kmip.SecretRole("admin",
            path=dev.path,
            scope=dev.scope,
            role="admin",
            tls_client_key_type="ec",
            tls_client_key_bits=256,
            operation_activate=True,
            operation_get=True,
            operation_get_attributes=True,
            operation_create=True,
            operation_destroy=True)
        ```

        ## Import

        KMIP Secret role can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:kmip/secretRole:SecretRole admin kmip
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] operation_activate: Grant permission to use the KMIP Activate operation.
        :param pulumi.Input[bool] operation_add_attribute: Grant permission to use the KMIP Add Attribute operation.
        :param pulumi.Input[bool] operation_all: Grant all permissions to this role. May not be specified with any other `operation_*` params.
        :param pulumi.Input[bool] operation_create: Grant permission to use the KMIP Create operation.
        :param pulumi.Input[bool] operation_destroy: Grant permission to use the KMIP Destroy operation.
        :param pulumi.Input[bool] operation_discover_versions: Grant permission to use the KMIP Discover Version operation.
        :param pulumi.Input[bool] operation_get: Grant permission to use the KMIP Get operation.
        :param pulumi.Input[bool] operation_get_attribute_list: Grant permission to use the KMIP Get Atrribute List operation.
        :param pulumi.Input[bool] operation_get_attributes: Grant permission to use the KMIP Get Atrributes operation.
        :param pulumi.Input[bool] operation_locate: Grant permission to use the KMIP Get Locate operation.
        :param pulumi.Input[bool] operation_none: Remove all permissions from this role. May not be specified with any other `operation_*` params.
        :param pulumi.Input[bool] operation_register: Grant permission to use the KMIP Register operation.
        :param pulumi.Input[bool] operation_rekey: Grant permission to use the KMIP Rekey operation.
        :param pulumi.Input[bool] operation_revoke: Grant permission to use the KMIP Revoke operation.
        :param pulumi.Input[str] path: The unique path this backend should be mounted at. Must
               not begin or end with a `/`. Defaults to `kmip`.
        :param pulumi.Input[str] role: Name of the role.
        :param pulumi.Input[str] scope: Name of the scope.
        :param pulumi.Input[int] tls_client_key_bits: Client certificate key bits, valid values depend on key type.
        :param pulumi.Input[str] tls_client_key_type: Client certificate key type, `rsa` or `ec`.
        :param pulumi.Input[int] tls_client_ttl: Client certificate TTL in seconds.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecretRoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages KMIP Secret roles in a Vault server. This feature requires
        Vault Enterprise. See the [Vault documentation](https://www.vaultproject.io/docs/secrets/kmip)
        for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        default = vault.kmip.SecretBackend("default",
            path="kmip",
            description="Vault KMIP backend")
        dev = vault.kmip.SecretScope("dev",
            path=default.path,
            scope="dev",
            force=True)
        admin = vault.kmip.SecretRole("admin",
            path=dev.path,
            scope=dev.scope,
            role="admin",
            tls_client_key_type="ec",
            tls_client_key_bits=256,
            operation_activate=True,
            operation_get=True,
            operation_get_attributes=True,
            operation_create=True,
            operation_destroy=True)
        ```

        ## Import

        KMIP Secret role can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:kmip/secretRole:SecretRole admin kmip
        ```

        :param str resource_name: The name of the resource.
        :param SecretRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 operation_activate: Optional[pulumi.Input[bool]] = None,
                 operation_add_attribute: Optional[pulumi.Input[bool]] = None,
                 operation_all: Optional[pulumi.Input[bool]] = None,
                 operation_create: Optional[pulumi.Input[bool]] = None,
                 operation_destroy: Optional[pulumi.Input[bool]] = None,
                 operation_discover_versions: Optional[pulumi.Input[bool]] = None,
                 operation_get: Optional[pulumi.Input[bool]] = None,
                 operation_get_attribute_list: Optional[pulumi.Input[bool]] = None,
                 operation_get_attributes: Optional[pulumi.Input[bool]] = None,
                 operation_locate: Optional[pulumi.Input[bool]] = None,
                 operation_none: Optional[pulumi.Input[bool]] = None,
                 operation_register: Optional[pulumi.Input[bool]] = None,
                 operation_rekey: Optional[pulumi.Input[bool]] = None,
                 operation_revoke: Optional[pulumi.Input[bool]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 tls_client_key_bits: Optional[pulumi.Input[int]] = None,
                 tls_client_key_type: Optional[pulumi.Input[str]] = None,
                 tls_client_ttl: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretRoleArgs.__new__(SecretRoleArgs)

            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["operation_activate"] = operation_activate
            __props__.__dict__["operation_add_attribute"] = operation_add_attribute
            __props__.__dict__["operation_all"] = operation_all
            __props__.__dict__["operation_create"] = operation_create
            __props__.__dict__["operation_destroy"] = operation_destroy
            __props__.__dict__["operation_discover_versions"] = operation_discover_versions
            __props__.__dict__["operation_get"] = operation_get
            __props__.__dict__["operation_get_attribute_list"] = operation_get_attribute_list
            __props__.__dict__["operation_get_attributes"] = operation_get_attributes
            __props__.__dict__["operation_locate"] = operation_locate
            __props__.__dict__["operation_none"] = operation_none
            __props__.__dict__["operation_register"] = operation_register
            __props__.__dict__["operation_rekey"] = operation_rekey
            __props__.__dict__["operation_revoke"] = operation_revoke
            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
            if scope is None and not opts.urn:
                raise TypeError("Missing required property 'scope'")
            __props__.__dict__["scope"] = scope
            __props__.__dict__["tls_client_key_bits"] = tls_client_key_bits
            __props__.__dict__["tls_client_key_type"] = tls_client_key_type
            __props__.__dict__["tls_client_ttl"] = tls_client_ttl
        super(SecretRole, __self__).__init__(
            'vault:kmip/secretRole:SecretRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            operation_activate: Optional[pulumi.Input[bool]] = None,
            operation_add_attribute: Optional[pulumi.Input[bool]] = None,
            operation_all: Optional[pulumi.Input[bool]] = None,
            operation_create: Optional[pulumi.Input[bool]] = None,
            operation_destroy: Optional[pulumi.Input[bool]] = None,
            operation_discover_versions: Optional[pulumi.Input[bool]] = None,
            operation_get: Optional[pulumi.Input[bool]] = None,
            operation_get_attribute_list: Optional[pulumi.Input[bool]] = None,
            operation_get_attributes: Optional[pulumi.Input[bool]] = None,
            operation_locate: Optional[pulumi.Input[bool]] = None,
            operation_none: Optional[pulumi.Input[bool]] = None,
            operation_register: Optional[pulumi.Input[bool]] = None,
            operation_rekey: Optional[pulumi.Input[bool]] = None,
            operation_revoke: Optional[pulumi.Input[bool]] = None,
            path: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None,
            scope: Optional[pulumi.Input[str]] = None,
            tls_client_key_bits: Optional[pulumi.Input[int]] = None,
            tls_client_key_type: Optional[pulumi.Input[str]] = None,
            tls_client_ttl: Optional[pulumi.Input[int]] = None) -> 'SecretRole':
        """
        Get an existing SecretRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] operation_activate: Grant permission to use the KMIP Activate operation.
        :param pulumi.Input[bool] operation_add_attribute: Grant permission to use the KMIP Add Attribute operation.
        :param pulumi.Input[bool] operation_all: Grant all permissions to this role. May not be specified with any other `operation_*` params.
        :param pulumi.Input[bool] operation_create: Grant permission to use the KMIP Create operation.
        :param pulumi.Input[bool] operation_destroy: Grant permission to use the KMIP Destroy operation.
        :param pulumi.Input[bool] operation_discover_versions: Grant permission to use the KMIP Discover Version operation.
        :param pulumi.Input[bool] operation_get: Grant permission to use the KMIP Get operation.
        :param pulumi.Input[bool] operation_get_attribute_list: Grant permission to use the KMIP Get Atrribute List operation.
        :param pulumi.Input[bool] operation_get_attributes: Grant permission to use the KMIP Get Atrributes operation.
        :param pulumi.Input[bool] operation_locate: Grant permission to use the KMIP Get Locate operation.
        :param pulumi.Input[bool] operation_none: Remove all permissions from this role. May not be specified with any other `operation_*` params.
        :param pulumi.Input[bool] operation_register: Grant permission to use the KMIP Register operation.
        :param pulumi.Input[bool] operation_rekey: Grant permission to use the KMIP Rekey operation.
        :param pulumi.Input[bool] operation_revoke: Grant permission to use the KMIP Revoke operation.
        :param pulumi.Input[str] path: The unique path this backend should be mounted at. Must
               not begin or end with a `/`. Defaults to `kmip`.
        :param pulumi.Input[str] role: Name of the role.
        :param pulumi.Input[str] scope: Name of the scope.
        :param pulumi.Input[int] tls_client_key_bits: Client certificate key bits, valid values depend on key type.
        :param pulumi.Input[str] tls_client_key_type: Client certificate key type, `rsa` or `ec`.
        :param pulumi.Input[int] tls_client_ttl: Client certificate TTL in seconds.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretRoleState.__new__(_SecretRoleState)

        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["operation_activate"] = operation_activate
        __props__.__dict__["operation_add_attribute"] = operation_add_attribute
        __props__.__dict__["operation_all"] = operation_all
        __props__.__dict__["operation_create"] = operation_create
        __props__.__dict__["operation_destroy"] = operation_destroy
        __props__.__dict__["operation_discover_versions"] = operation_discover_versions
        __props__.__dict__["operation_get"] = operation_get
        __props__.__dict__["operation_get_attribute_list"] = operation_get_attribute_list
        __props__.__dict__["operation_get_attributes"] = operation_get_attributes
        __props__.__dict__["operation_locate"] = operation_locate
        __props__.__dict__["operation_none"] = operation_none
        __props__.__dict__["operation_register"] = operation_register
        __props__.__dict__["operation_rekey"] = operation_rekey
        __props__.__dict__["operation_revoke"] = operation_revoke
        __props__.__dict__["path"] = path
        __props__.__dict__["role"] = role
        __props__.__dict__["scope"] = scope
        __props__.__dict__["tls_client_key_bits"] = tls_client_key_bits
        __props__.__dict__["tls_client_key_type"] = tls_client_key_type
        __props__.__dict__["tls_client_ttl"] = tls_client_ttl
        return SecretRole(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="operationActivate")
    def operation_activate(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Activate operation.
        """
        return pulumi.get(self, "operation_activate")

    @property
    @pulumi.getter(name="operationAddAttribute")
    def operation_add_attribute(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Add Attribute operation.
        """
        return pulumi.get(self, "operation_add_attribute")

    @property
    @pulumi.getter(name="operationAll")
    def operation_all(self) -> pulumi.Output[bool]:
        """
        Grant all permissions to this role. May not be specified with any other `operation_*` params.
        """
        return pulumi.get(self, "operation_all")

    @property
    @pulumi.getter(name="operationCreate")
    def operation_create(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Create operation.
        """
        return pulumi.get(self, "operation_create")

    @property
    @pulumi.getter(name="operationDestroy")
    def operation_destroy(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Destroy operation.
        """
        return pulumi.get(self, "operation_destroy")

    @property
    @pulumi.getter(name="operationDiscoverVersions")
    def operation_discover_versions(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Discover Version operation.
        """
        return pulumi.get(self, "operation_discover_versions")

    @property
    @pulumi.getter(name="operationGet")
    def operation_get(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Get operation.
        """
        return pulumi.get(self, "operation_get")

    @property
    @pulumi.getter(name="operationGetAttributeList")
    def operation_get_attribute_list(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Get Atrribute List operation.
        """
        return pulumi.get(self, "operation_get_attribute_list")

    @property
    @pulumi.getter(name="operationGetAttributes")
    def operation_get_attributes(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Get Atrributes operation.
        """
        return pulumi.get(self, "operation_get_attributes")

    @property
    @pulumi.getter(name="operationLocate")
    def operation_locate(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Get Locate operation.
        """
        return pulumi.get(self, "operation_locate")

    @property
    @pulumi.getter(name="operationNone")
    def operation_none(self) -> pulumi.Output[bool]:
        """
        Remove all permissions from this role. May not be specified with any other `operation_*` params.
        """
        return pulumi.get(self, "operation_none")

    @property
    @pulumi.getter(name="operationRegister")
    def operation_register(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Register operation.
        """
        return pulumi.get(self, "operation_register")

    @property
    @pulumi.getter(name="operationRekey")
    def operation_rekey(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Rekey operation.
        """
        return pulumi.get(self, "operation_rekey")

    @property
    @pulumi.getter(name="operationRevoke")
    def operation_revoke(self) -> pulumi.Output[bool]:
        """
        Grant permission to use the KMIP Revoke operation.
        """
        return pulumi.get(self, "operation_revoke")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[str]:
        """
        The unique path this backend should be mounted at. Must
        not begin or end with a `/`. Defaults to `kmip`.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        """
        Name of the role.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter
    def scope(self) -> pulumi.Output[str]:
        """
        Name of the scope.
        """
        return pulumi.get(self, "scope")

    @property
    @pulumi.getter(name="tlsClientKeyBits")
    def tls_client_key_bits(self) -> pulumi.Output[Optional[int]]:
        """
        Client certificate key bits, valid values depend on key type.
        """
        return pulumi.get(self, "tls_client_key_bits")

    @property
    @pulumi.getter(name="tlsClientKeyType")
    def tls_client_key_type(self) -> pulumi.Output[Optional[str]]:
        """
        Client certificate key type, `rsa` or `ec`.
        """
        return pulumi.get(self, "tls_client_key_type")

    @property
    @pulumi.getter(name="tlsClientTtl")
    def tls_client_ttl(self) -> pulumi.Output[Optional[int]]:
        """
        Client certificate TTL in seconds.
        """
        return pulumi.get(self, "tls_client_ttl")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SecretBackendCaArgs', 'SecretBackendCa']

@pulumi.input_type
class SecretBackendCaArgs:
    def __init__(__self__, *,
                 backend: Optional[pulumi.Input[str]] = None,
                 generate_signing_key: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 public_key: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SecretBackendCa resource.
        :param pulumi.Input[str] backend: The path where the SSH secret backend is mounted. Defaults to 'ssh'
        :param pulumi.Input[bool] generate_signing_key: Whether Vault should generate the signing key pair internally. Defaults to true
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] private_key: Private key part the SSH CA key pair; required if generate_signing_key is false.
        :param pulumi.Input[str] public_key: The public key part the SSH CA key pair; required if generate_signing_key is false.
        """
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if generate_signing_key is not None:
            pulumi.set(__self__, "generate_signing_key", generate_signing_key)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        The path where the SSH secret backend is mounted. Defaults to 'ssh'
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="generateSigningKey")
    def generate_signing_key(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether Vault should generate the signing key pair internally. Defaults to true
        """
        return pulumi.get(self, "generate_signing_key")

    @generate_signing_key.setter
    def generate_signing_key(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "generate_signing_key", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[str]]:
        """
        Private key part the SSH CA key pair; required if generate_signing_key is false.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[str]]:
        """
        The public key part the SSH CA key pair; required if generate_signing_key is false.
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "public_key", value)


@pulumi.input_type
class _SecretBackendCaState:
    def __init__(__self__, *,
                 backend: Optional[pulumi.Input[str]] = None,
                 generate_signing_key: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 public_key: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SecretBackendCa resources.
        :param pulumi.Input[str] backend: The path where the SSH secret backend is mounted. Defaults to 'ssh'
        :param pulumi.Input[bool] generate_signing_key: Whether Vault should generate the signing key pair internally. Defaults to true
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] private_key: Private key part the SSH CA key pair; required if generate_signing_key is false.
        :param pulumi.Input[str] public_key: The public key part the SSH CA key pair; required if generate_signing_key is false.
        """
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if generate_signing_key is not None:
            pulumi.set(__self__, "generate_signing_key", generate_signing_key)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        The path where the SSH secret backend is mounted. Defaults to 'ssh'
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="generateSigningKey")
    def generate_signing_key(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether Vault should generate the signing key pair internally. Defaults to true
        """
        return pulumi.get(self, "generate_signing_key")

    @generate_signing_key.setter
    def generate_signing_key(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "generate_signing_key", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[str]]:
        """
        Private key part the SSH CA key pair; required if generate_signing_key is false.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[str]]:
        """
        The public key part the SSH CA key pair; required if generate_signing_key is false.
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "public_key", value)


class SecretBackendCa(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 generate_signing_key: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 public_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a resource to manage CA information in an SSH secret backend
        [SSH secret backend within Vault](https://www.vaultproject.io/docs/secrets/ssh/index.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        example = vault.Mount("example", type="ssh")
        foo = vault.ssh.SecretBackendCa("foo", backend=example.path)
        ```

        ## Import

        SSH secret backend CAs can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:ssh/secretBackendCa:SecretBackendCa foo ssh
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: The path where the SSH secret backend is mounted. Defaults to 'ssh'
        :param pulumi.Input[bool] generate_signing_key: Whether Vault should generate the signing key pair internally. Defaults to true
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] private_key: Private key part the SSH CA key pair; required if generate_signing_key is false.
        :param pulumi.Input[str] public_key: The public key part the SSH CA key pair; required if generate_signing_key is false.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SecretBackendCaArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to manage CA information in an SSH secret backend
        [SSH secret backend within Vault](https://www.vaultproject.io/docs/secrets/ssh/index.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        example = vault.Mount("example", type="ssh")
        foo = vault.ssh.SecretBackendCa("foo", backend=example.path)
        ```

        ## Import

        SSH secret backend CAs can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:ssh/secretBackendCa:SecretBackendCa foo ssh
        ```

        :param str resource_name: The name of the resource.
        :param SecretBackendCaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretBackendCaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 generate_signing_key: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 public_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretBackendCaArgs.__new__(SecretBackendCaArgs)

            __props__.__dict__["backend"] = backend
            __props__.__dict__["generate_signing_key"] = generate_signing_key
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["private_key"] = None if private_key is None else pulumi.Output.secret(private_key)
            __props__.__dict__["public_key"] = public_key
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["privateKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SecretBackendCa, __self__).__init__(
            'vault:ssh/secretBackendCa:SecretBackendCa',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend: Optional[pulumi.Input[str]] = None,
            generate_signing_key: Optional[pulumi.Input[bool]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            private_key: Optional[pulumi.Input[str]] = None,
            public_key: Optional[pulumi.Input[str]] = None) -> 'SecretBackendCa':
        """
        Get an existing SecretBackendCa resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: The path where the SSH secret backend is mounted. Defaults to 'ssh'
        :param pulumi.Input[bool] generate_signing_key: Whether Vault should generate the signing key pair internally. Defaults to true
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] private_key: Private key part the SSH CA key pair; required if generate_signing_key is false.
        :param pulumi.Input[str] public_key: The public key part the SSH CA key pair; required if generate_signing_key is false.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretBackendCaState.__new__(_SecretBackendCaState)

        __props__.__dict__["backend"] = backend
        __props__.__dict__["generate_signing_key"] = generate_signing_key
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["private_key"] = private_key
        __props__.__dict__["public_key"] = public_key
        return SecretBackendCa(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Output[Optional[str]]:
        """
        The path where the SSH secret backend is mounted. Defaults to 'ssh'
        """
        return pulumi.get(self, "backend")

    @property
    @pulumi.getter(name="generateSigningKey")
    def generate_signing_key(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether Vault should generate the signing key pair internally. Defaults to true
        """
        return pulumi.get(self, "generate_signing_key")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Output[str]:
        """
        Private key part the SSH CA key pair; required if generate_signing_key is false.
        """
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> pulumi.Output[str]:
        """
        The public key part the SSH CA key pair; required if generate_signing_key is false.
        """
        return pulumi.get(self, "public_key")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SecretImpersonatedAccountArgs', 'SecretImpersonatedAccount']

@pulumi.input_type
class SecretImpersonatedAccountArgs:
    def __init__(__self__, *,
                 backend: pulumi.Input[str],
                 impersonated_account: pulumi.Input[str],
                 service_account_email: pulumi.Input[str],
                 namespace: Optional[pulumi.Input[str]] = None,
                 token_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SecretImpersonatedAccount resource.
        :param pulumi.Input[str] backend: Path where the GCP Secrets Engine is mounted
        :param pulumi.Input[str] impersonated_account: Name of the Impersonated Account to create
        :param pulumi.Input[str] service_account_email: Email of the GCP service account to impersonate.
        :param pulumi.Input[str] namespace: Target namespace. (requires Enterprise)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] token_scopes: List of OAuth scopes to assign to access tokens generated under this impersonated account.
        """
        pulumi.set(__self__, "backend", backend)
        pulumi.set(__self__, "impersonated_account", impersonated_account)
        pulumi.set(__self__, "service_account_email", service_account_email)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if token_scopes is not None:
            pulumi.set(__self__, "token_scopes", token_scopes)

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Input[str]:
        """
        Path where the GCP Secrets Engine is mounted
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: pulumi.Input[str]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="impersonatedAccount")
    def impersonated_account(self) -> pulumi.Input[str]:
        """
        Name of the Impersonated Account to create
        """
        return pulumi.get(self, "impersonated_account")

    @impersonated_account.setter
    def impersonated_account(self, value: pulumi.Input[str]):
        pulumi.set(self, "impersonated_account", value)

    @property
    @pulumi.getter(name="serviceAccountEmail")
    def service_account_email(self) -> pulumi.Input[str]:
        """
        Email of the GCP service account to impersonate.
        """
        return pulumi.get(self, "service_account_email")

    @service_account_email.setter
    def service_account_email(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_account_email", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        Target namespace. (requires Enterprise)
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="tokenScopes")
    def token_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of OAuth scopes to assign to access tokens generated under this impersonated account.
        """
        return pulumi.get(self, "token_scopes")

    @token_scopes.setter
    def token_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "token_scopes", value)


@pulumi.input_type
class _SecretImpersonatedAccountState:
    def __init__(__self__, *,
                 backend: Optional[pulumi.Input[str]] = None,
                 impersonated_account: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 service_account_email: Optional[pulumi.Input[str]] = None,
                 service_account_project: Optional[pulumi.Input[str]] = None,
                 token_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SecretImpersonatedAccount resources.
        :param pulumi.Input[str] backend: Path where the GCP Secrets Engine is mounted
        :param pulumi.Input[str] impersonated_account: Name of the Impersonated Account to create
        :param pulumi.Input[str] namespace: Target namespace. (requires Enterprise)
        :param pulumi.Input[str] service_account_email: Email of the GCP service account to impersonate.
        :param pulumi.Input[str] service_account_project: Project the service account belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] token_scopes: List of OAuth scopes to assign to access tokens generated under this impersonated account.
        """
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if impersonated_account is not None:
            pulumi.set(__self__, "impersonated_account", impersonated_account)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if service_account_email is not None:
            pulumi.set(__self__, "service_account_email", service_account_email)
        if service_account_project is not None:
            pulumi.set(__self__, "service_account_project", service_account_project)
        if token_scopes is not None:
            pulumi.set(__self__, "token_scopes", token_scopes)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        Path where the GCP Secrets Engine is mounted
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="impersonatedAccount")
    def impersonated_account(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Impersonated Account to create
        """
        return pulumi.get(self, "impersonated_account")

    @impersonated_account.setter
    def impersonated_account(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "impersonated_account", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        Target namespace. (requires Enterprise)
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="serviceAccountEmail")
    def service_account_email(self) -> Optional[pulumi.Input[str]]:
        """
        Email of the GCP service account to impersonate.
        """
        return pulumi.get(self, "service_account_email")

    @service_account_email.setter
    def service_account_email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_account_email", value)

    @property
    @pulumi.getter(name="serviceAccountProject")
    def service_account_project(self) -> Optional[pulumi.Input[str]]:
        """
        Project the service account belongs to.
        """
        return pulumi.get(self, "service_account_project")

    @service_account_project.setter
    def service_account_project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_account_project", value)

    @property
    @pulumi.getter(name="tokenScopes")
    def token_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of OAuth scopes to assign to access tokens generated under this impersonated account.
        """
        return pulumi.get(self, "token_scopes")

    @token_scopes.setter
    def token_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "token_scopes", value)


class SecretImpersonatedAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 impersonated_account: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 service_account_email: Optional[pulumi.Input[str]] = None,
                 token_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Creates a Impersonated Account in the [GCP Secrets Engine](https://www.vaultproject.io/docs/secrets/gcp/index.html) for Vault.

        Each [impersonated account](https://www.vaultproject.io/docs/secrets/gcp/index.html#impersonated-accounts) is tied to a separately managed
        Service Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gcp as gcp
        import pulumi_vault as vault

        this = gcp.service_account.Account("this", account_id="my-awesome-account")
        gcp = vault.gcp.SecretBackend("gcp",
            path="gcp",
            credentials=(lambda path: open(path).read())("credentials.json"))
        impersonated_account = vault.gcp.SecretImpersonatedAccount("impersonatedAccount",
            backend=gcp.path,
            impersonated_account="this",
            service_account_email=this.email,
            token_scopes=["https://www.googleapis.com/auth/cloud-platform"])
        ```

        ## Import

        A impersonated account can be imported using its Vault Path. For example, referencing the example above,

        ```sh
         $ pulumi import vault:gcp/secretImpersonatedAccount:SecretImpersonatedAccount impersonated_account gcp/impersonated-account/project_viewer
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: Path where the GCP Secrets Engine is mounted
        :param pulumi.Input[str] impersonated_account: Name of the Impersonated Account to create
        :param pulumi.Input[str] namespace: Target namespace. (requires Enterprise)
        :param pulumi.Input[str] service_account_email: Email of the GCP service account to impersonate.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] token_scopes: List of OAuth scopes to assign to access tokens generated under this impersonated account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecretImpersonatedAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a Impersonated Account in the [GCP Secrets Engine](https://www.vaultproject.io/docs/secrets/gcp/index.html) for Vault.

        Each [impersonated account](https://www.vaultproject.io/docs/secrets/gcp/index.html#impersonated-accounts) is tied to a separately managed
        Service Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gcp as gcp
        import pulumi_vault as vault

        this = gcp.service_account.Account("this", account_id="my-awesome-account")
        gcp = vault.gcp.SecretBackend("gcp",
            path="gcp",
            credentials=(lambda path: open(path).read())("credentials.json"))
        impersonated_account = vault.gcp.SecretImpersonatedAccount("impersonatedAccount",
            backend=gcp.path,
            impersonated_account="this",
            service_account_email=this.email,
            token_scopes=["https://www.googleapis.com/auth/cloud-platform"])
        ```

        ## Import

        A impersonated account can be imported using its Vault Path. For example, referencing the example above,

        ```sh
         $ pulumi import vault:gcp/secretImpersonatedAccount:SecretImpersonatedAccount impersonated_account gcp/impersonated-account/project_viewer
        ```

        :param str resource_name: The name of the resource.
        :param SecretImpersonatedAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretImpersonatedAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 impersonated_account: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 service_account_email: Optional[pulumi.Input[str]] = None,
                 token_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretImpersonatedAccountArgs.__new__(SecretImpersonatedAccountArgs)

            if backend is None and not opts.urn:
                raise TypeError("Missing required property 'backend'")
            __props__.__dict__["backend"] = backend
            if impersonated_account is None and not opts.urn:
                raise TypeError("Missing required property 'impersonated_account'")
            __props__.__dict__["impersonated_account"] = impersonated_account
            __props__.__dict__["namespace"] = namespace
            if service_account_email is None and not opts.urn:
                raise TypeError("Missing required property 'service_account_email'")
            __props__.__dict__["service_account_email"] = service_account_email
            __props__.__dict__["token_scopes"] = token_scopes
            __props__.__dict__["service_account_project"] = None
        super(SecretImpersonatedAccount, __self__).__init__(
            'vault:gcp/secretImpersonatedAccount:SecretImpersonatedAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend: Optional[pulumi.Input[str]] = None,
            impersonated_account: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            service_account_email: Optional[pulumi.Input[str]] = None,
            service_account_project: Optional[pulumi.Input[str]] = None,
            token_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'SecretImpersonatedAccount':
        """
        Get an existing SecretImpersonatedAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend: Path where the GCP Secrets Engine is mounted
        :param pulumi.Input[str] impersonated_account: Name of the Impersonated Account to create
        :param pulumi.Input[str] namespace: Target namespace. (requires Enterprise)
        :param pulumi.Input[str] service_account_email: Email of the GCP service account to impersonate.
        :param pulumi.Input[str] service_account_project: Project the service account belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] token_scopes: List of OAuth scopes to assign to access tokens generated under this impersonated account.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretImpersonatedAccountState.__new__(_SecretImpersonatedAccountState)

        __props__.__dict__["backend"] = backend
        __props__.__dict__["impersonated_account"] = impersonated_account
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["service_account_email"] = service_account_email
        __props__.__dict__["service_account_project"] = service_account_project
        __props__.__dict__["token_scopes"] = token_scopes
        return SecretImpersonatedAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Output[str]:
        """
        Path where the GCP Secrets Engine is mounted
        """
        return pulumi.get(self, "backend")

    @property
    @pulumi.getter(name="impersonatedAccount")
    def impersonated_account(self) -> pulumi.Output[str]:
        """
        Name of the Impersonated Account to create
        """
        return pulumi.get(self, "impersonated_account")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        Target namespace. (requires Enterprise)
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="serviceAccountEmail")
    def service_account_email(self) -> pulumi.Output[str]:
        """
        Email of the GCP service account to impersonate.
        """
        return pulumi.get(self, "service_account_email")

    @property
    @pulumi.getter(name="serviceAccountProject")
    def service_account_project(self) -> pulumi.Output[str]:
        """
        Project the service account belongs to.
        """
        return pulumi.get(self, "service_account_project")

    @property
    @pulumi.getter(name="tokenScopes")
    def token_scopes(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of OAuth scopes to assign to access tokens generated under this impersonated account.
        """
        return pulumi.get(self, "token_scopes")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['EgpPolicyArgs', 'EgpPolicy']

@pulumi.input_type
class EgpPolicyArgs:
    def __init__(__self__, *,
                 enforcement_level: pulumi.Input[str],
                 paths: pulumi.Input[Sequence[pulumi.Input[str]]],
                 policy: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a EgpPolicy resource.
        :param pulumi.Input[str] enforcement_level: Enforcement level of Sentinel policy. Can be either `advisory` or `soft-mandatory` or `hard-mandatory`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of paths to which the policy will be applied to
        :param pulumi.Input[str] policy: String containing a Sentinel policy
        :param pulumi.Input[str] name: The name of the policy
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        """
        pulumi.set(__self__, "enforcement_level", enforcement_level)
        pulumi.set(__self__, "paths", paths)
        pulumi.set(__self__, "policy", policy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter(name="enforcementLevel")
    def enforcement_level(self) -> pulumi.Input[str]:
        """
        Enforcement level of Sentinel policy. Can be either `advisory` or `soft-mandatory` or `hard-mandatory`
        """
        return pulumi.get(self, "enforcement_level")

    @enforcement_level.setter
    def enforcement_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "enforcement_level", value)

    @property
    @pulumi.getter
    def paths(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        List of paths to which the policy will be applied to
        """
        return pulumi.get(self, "paths")

    @paths.setter
    def paths(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "paths", value)

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Input[str]:
        """
        String containing a Sentinel policy
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the policy
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)


@pulumi.input_type
class _EgpPolicyState:
    def __init__(__self__, *,
                 enforcement_level: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 policy: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EgpPolicy resources.
        :param pulumi.Input[str] enforcement_level: Enforcement level of Sentinel policy. Can be either `advisory` or `soft-mandatory` or `hard-mandatory`
        :param pulumi.Input[str] name: The name of the policy
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of paths to which the policy will be applied to
        :param pulumi.Input[str] policy: String containing a Sentinel policy
        """
        if enforcement_level is not None:
            pulumi.set(__self__, "enforcement_level", enforcement_level)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if paths is not None:
            pulumi.set(__self__, "paths", paths)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)

    @property
    @pulumi.getter(name="enforcementLevel")
    def enforcement_level(self) -> Optional[pulumi.Input[str]]:
        """
        Enforcement level of Sentinel policy. Can be either `advisory` or `soft-mandatory` or `hard-mandatory`
        """
        return pulumi.get(self, "enforcement_level")

    @enforcement_level.setter
    def enforcement_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enforcement_level", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the policy
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of paths to which the policy will be applied to
        """
        return pulumi.get(self, "paths")

    @paths.setter
    def paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "paths", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        String containing a Sentinel policy
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)


class EgpPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enforcement_level: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a resource to manage Endpoint Governing Policy (EGP) via [Sentinel](https://www.vaultproject.io/docs/enterprise/sentinel/index.html).

        **Note** this feature is available only with Vault Enterprise.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        allow_all = vault.EgpPolicy("allow-all",
            enforcement_level="soft-mandatory",
            paths=["*"],
            policy=\"\"\"main = rule {
          true
        }

        \"\"\")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] enforcement_level: Enforcement level of Sentinel policy. Can be either `advisory` or `soft-mandatory` or `hard-mandatory`
        :param pulumi.Input[str] name: The name of the policy
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of paths to which the policy will be applied to
        :param pulumi.Input[str] policy: String containing a Sentinel policy
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EgpPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to manage Endpoint Governing Policy (EGP) via [Sentinel](https://www.vaultproject.io/docs/enterprise/sentinel/index.html).

        **Note** this feature is available only with Vault Enterprise.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        allow_all = vault.EgpPolicy("allow-all",
            enforcement_level="soft-mandatory",
            paths=["*"],
            policy=\"\"\"main = rule {
          true
        }

        \"\"\")
        ```

        :param str resource_name: The name of the resource.
        :param EgpPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EgpPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enforcement_level: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EgpPolicyArgs.__new__(EgpPolicyArgs)

            if enforcement_level is None and not opts.urn:
                raise TypeError("Missing required property 'enforcement_level'")
            __props__.__dict__["enforcement_level"] = enforcement_level
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            if paths is None and not opts.urn:
                raise TypeError("Missing required property 'paths'")
            __props__.__dict__["paths"] = paths
            if policy is None and not opts.urn:
                raise TypeError("Missing required property 'policy'")
            __props__.__dict__["policy"] = policy
        super(EgpPolicy, __self__).__init__(
            'vault:index/egpPolicy:EgpPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enforcement_level: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            policy: Optional[pulumi.Input[str]] = None) -> 'EgpPolicy':
        """
        Get an existing EgpPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] enforcement_level: Enforcement level of Sentinel policy. Can be either `advisory` or `soft-mandatory` or `hard-mandatory`
        :param pulumi.Input[str] name: The name of the policy
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of paths to which the policy will be applied to
        :param pulumi.Input[str] policy: String containing a Sentinel policy
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EgpPolicyState.__new__(_EgpPolicyState)

        __props__.__dict__["enforcement_level"] = enforcement_level
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["paths"] = paths
        __props__.__dict__["policy"] = policy
        return EgpPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="enforcementLevel")
    def enforcement_level(self) -> pulumi.Output[str]:
        """
        Enforcement level of Sentinel policy. Can be either `advisory` or `soft-mandatory` or `hard-mandatory`
        """
        return pulumi.get(self, "enforcement_level")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the policy
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def paths(self) -> pulumi.Output[Sequence[str]]:
        """
        List of paths to which the policy will be applied to
        """
        return pulumi.get(self, "paths")

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Output[str]:
        """
        String containing a Sentinel policy
        """
        return pulumi.get(self, "policy")

